% Checks if the current m is feasible considering the condition:
% for any tau_i exists k = 1...m such that kCi + Wi <= kPiDi
function feasible = check_m_feasibility(m, Pi, tasks, schedPolicy)

for i = 1:numel(tasks)
    Ci = tasks(i).C;
    Di = tasks(i).D;
    
    if (strcmp(schedPolicy,'GEDF'))
        Wi = tasks(i).Wedf;
    elseif (strcmp(schedPolicy,'FP'))
        Wi = tasks(i).Wfp;
    else
        disp('Cannot check feasibility of m: unknown scheduling policy');
        feasible = 0;
        return;
    end
    
    feasible = 0;
    
    for k = 1:m
        if (k*Ci + Wi <= k*Pi*Di)
            feasible = 1;
            break;
        end
    end
    
    if (feasible == 0)
        % There is no k = 1,..,m for tau_i and
        % m is infeasible
        return;
    end
end

% For all tau_i
% m is feasible
feasible = 1;

end