% Computes the psf k function of the GMPR interface (Y_k(deltaT))
function psfKValue = gmpr_psf_k(k, thetas, deltaT, Pi)

% Get critical time instants to check sbf value
timeInstants = get_psf_critical_time_instants(thetas);

number_of_cases = numel(timeInstants);

for l=1:number_of_cases
    
    t = timeInstants(l);
    
    supplyKt = get_supply_k(k, thetas, Pi, t, deltaT);
    
    if (l == 1)
        psfKValue = supplyKt;
    else
        psfKValue = min(supplyKt, psfKValue);
    end
end

end



% Gets critical time instants to compute the psf values.
% These are values of t*_i defined in the paper
function T = get_psf_critical_time_instants(thetas)

m = numel(thetas);
T = zeros(m,1);

for i = 1:m
    if (i == 1)
        T(1) = thetas(1);
    else
        T(i) = thetas(i) - thetas(i-1);
    end
end

T = unique(T);

end



% Gets supply value within the time window (t, t + deltaT)
% considering the worst-case execution pattern
function supplyKValue = get_supply_k(k, thetas, Pi, t, deltaT)

% A
for j = 1:k
    
    if (j == 1)
        A = min(t + deltaT, thetas(j) - 0) - min(t, thetas(j) - 0);
    else
        A = A + (min(t + deltaT, thetas(j) - thetas(j-1)) - min(t, thetas(j) - thetas(j-1)));
    end
end

% B
B = thetas(k)*(floor((max(t + deltaT - Pi, 0))/Pi) - floor((max(t - Pi, 0))/Pi));

% C
for j = 1:k
    if (j == 1)
        C = max(mod(max(t + deltaT - Pi, 0), Pi) - (Pi - thetas(j)), 0);
    else
        C = C + max(mod(max(t + deltaT - Pi, 0), Pi) - (Pi - (thetas(j) - thetas(j-1))), 0);
    end
end

% D
for j = 1:k
    if (j == 1)
        D = max(mod(max(t - Pi, 0), Pi) - (Pi - thetas(j)), 0);
    else
        D = D + max(0, mod(max(t - Pi, 0), Pi) - (Pi - (thetas(j) - thetas(j-1))));
    end
end

supplyKValue = A + B + (C - D);

end