% Plots the functions U(interface) = function(Pi)
function plot_interface_Us_for_Pis(Pis, GmprUs_EDF, MprUs_EDF, GmprUs_FP, MprUs_FP, plotTitle, schedPolicy)

PiMin = Pis(1);
PiMax = Pis(end);

% Creation of plots
if (~strcmp(schedPolicy,'FP'))
    h1 = plot(Pis, GmprUs_EDF, '-x', 'LineWidth', 1, 'Color', 'black');
    hold on;
    h2 = plot(Pis, MprUs_EDF, '-o', 'LineWidth', 1, 'Color', 'black');
    hold on;
end

if (~strcmp(schedPolicy,'GEDF'))
    h3 = plot(Pis, GmprUs_FP, '-s', 'LineWidth', 1, 'Color', 'blue');
    hold on;
    h4 = plot(Pis, MprUs_FP, '-^', 'LineWidth', 1, 'Color', 'blue');
end

% General Settings
set(gcf, 'Position', [0 0 1200 800]);
whitebg('white');

grid on;
xlabel('Interface period     \Pi', 'FontSize', 12)
ylabel('Interface utilization      \Theta_m / \Pi', 'FontSize', 12)

% Legend
if (strcmp(schedPolicy,'GEDF'))
    legend([h1 h2], {'GMPR EDF', 'MPR EDF'});
    MprMinU = min(MprUs_EDF(PiMin:end));
    GmprMinU = min(GmprUs_EDF(PiMin:end));
    MprMaxU = max(MprUs_EDF(PiMin:end));
    GmprMaxU = max(GmprUs_EDF(PiMin:end));
elseif (strcmp(schedPolicy,'FP'))
    legend([h3 h4], {'GMPR FP', 'MPR FP'});
    MprMinU = min(MprUs_FP(PiMin:end));
    GmprMinU = min(GmprUs_FP(PiMin:end));
    MprMaxU = max(MprUs_FP(PiMin:end));
    GmprMaxU = max(GmprUs_FP(PiMin:end));
else
    legend([h1 h2 h3 h4], {'GMPR EDF', 'MPR EDF', 'GMPR FP', 'MPR FP'});
    MprMinU = min(min(MprUs_EDF(PiMin:end)),min(MprUs_FP(PiMin:end)));
    GmprMinU = min(min(GmprUs_EDF(PiMin:end)),min(GmprUs_FP(PiMin:end)));
    MprMaxU = max(max(MprUs_EDF(PiMin:end)),max(MprUs_FP(PiMin:end)));
    GmprMaxU = max(max(GmprUs_EDF(PiMin:end)),max(GmprUs_FP(PiMin:end)));
end

% Title
title(plotTitle, 'FontWeight', 'bold', 'FontSize', 12, 'Color', 'black')

% Range of axises
axis([PiMin PiMax min(MprMinU,GmprMinU)-0.2 max(MprMaxU,GmprMaxU)+0.2]);

end